Hex v0.17.6 mix hex.config View Source
Reads, updates or deletes local Hex configuration.
mix hex.config KEY [VALUE]
Config keys
api_url- Hex API URL. Can be overridden by setting the environment variableHEX_API_URL(Default:"https://hex.pm/api")offline- If set to true Hex will not fetch the registry or packages and will instead use locally cached files if they are available. Can be overridden by setting the environment variableHEX_OFFLINE(Default:false)unsafe_https- If set to true Hex will not verify HTTPS certificates. Can be overridden by setting the environment variableHEX_UNSAFE_HTTPS(Default:false)unsafe_registry- If set to true Hex will not verify the registry signature against the repository's public key. Can be overridden by setting the environment variableHEX_UNSAFE_REGISTRY(Default:false)http_proxy- HTTP proxy server. Can be overridden by setting the environment variableHTTP_PROXYhttps_proxy- HTTPS proxy server. Can be overridden by setting the environment variableHTTPS_PROXYhttp_concurrency- Limits the number of concurrent HTTP requests in flight. Can be overridden by setting the environment variableHEX_HTTP_CONCURRENCY(Default:8)http_timeout- Sets the timeout for HTTP requests in seconds. Can be overridden by setting the environment variableHEX_HTTP_TIMEOUT
HEX_HOME environment variable can be set to point to the directory where Hex
stores the cache and configuration (Default: ~/.hex)
Command line options
--delete- Remove a specific config key
Link to this section Summary
Functions
Callback implementation for Mix.Task.run/1.
Link to this section Functions
Callback implementation for Mix.Task.run/1.